==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/InstanceIpv6Address.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InstanceIpv6Address(
    ipv6Address: Optional[String] = Optional.Absent,
    isPrimaryIpv6: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceIpv6Address = {
    import InstanceIpv6Address.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
      .builder()
      .optionallyWith(ipv6Address.map(value => value: java.lang.String))(
        _.ipv6Address
      )
      .optionallyWith(isPrimaryIpv6.map(value => value: java.lang.Boolean))(
        _.isPrimaryIpv6
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.InstanceIpv6Address.ReadOnly =
    zio.aws.ec2.model.InstanceIpv6Address.wrap(buildAwsValue())
}
object InstanceIpv6Address {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceIpv6Address =
      zio.aws.ec2.model.InstanceIpv6Address(
        ipv6Address.map(value => value),
        isPrimaryIpv6.map(value => value)
      )
    def ipv6Address: Optional[String]
    def isPrimaryIpv6: Optional[Boolean]
    def getIpv6Address: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipv6Address", ipv6Address)
    def getIsPrimaryIpv6: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isPrimaryIpv6", isPrimaryIpv6)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
  ) extends zio.aws.ec2.model.InstanceIpv6Address.ReadOnly {
    override val ipv6Address: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.ipv6Address())
      .map(value => value: String)
    override val isPrimaryIpv6: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.isPrimaryIpv6())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
  ): zio.aws.ec2.model.InstanceIpv6Address.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.102.9-sources.jar: zio/aws/ec2/model/InstanceIpv6Address.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InstanceIpv6Address(ipv6Address: Option[String] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceIpv6Address = {
    import InstanceIpv6Address.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
      .builder()
      .optionallyWith(ipv6Address.map(value => value: java.lang.String))(
        _.ipv6Address
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.InstanceIpv6Address.ReadOnly =
    zio.aws.ec2.model.InstanceIpv6Address.wrap(buildAwsValue())
}
object InstanceIpv6Address {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceIpv6Address =
      zio.aws.ec2.model.InstanceIpv6Address(ipv6Address.map(value => value))
    def ipv6Address: Option[String]
    def getIpv6Address: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipv6Address", ipv6Address)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
  ) extends zio.aws.ec2.model.InstanceIpv6Address.ReadOnly {
    override val ipv6Address: Option[String] =
      scala.Option(impl.ipv6Address()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceIpv6Address
  ): zio.aws.ec2.model.InstanceIpv6Address.ReadOnly = new Wrapper(impl)
}
